import { useModel } from '@/.umi/plugin-model/useModel';
import { confirm } from '@/components/AModal';
import OssImage from '@/components/OssImage';
import SvgIcon from '@/components/SvgIcon';
import { logout } from '@/services/user';
import { RightOutlined, QuestionOutlined } from '@ant-design/icons';
import { Button, Popover, Modal } from 'antd';
import classNames from 'classnames';
import React, { CSSProperties } from 'react';
import { useCallback } from 'react';
import { useState } from 'react';
import styles from './UserCenter.less';

interface UserCenterProps {
  className?: string;
  style?: CSSProperties;
}

export default function UserCenter(props: UserCenterProps) {
  const { className } = props;
  const [popVisible, setPopVisible] = useState(false);

  const onVisibleChange = useCallback((nextVisible) => {
    setPopVisible(nextVisible);
  }, [])

  return (
    <Popover
      overlayClassName={styles.popWrapper}
      content={<PopContent />}
      trigger="click"
      visible={popVisible}
      onVisibleChange={onVisibleChange}
      placement="bottomRight"
      arrowContent={() => null}
    >
      <Button type="link" className={classNames(styles.btn, className)}>
        <SvgIcon className={classNames(styles.icon, popVisible ? styles.active : '')} xlinkHref="usercenter" />
      </Button>
    </Popover>
  )
}

function PopContent(props) {
  const { initialState: { currentUser } = {} } = useModel('@@initialState');
  console.log(currentUser);

  const tryLogout = useCallback(() => {
    confirm({
      onOk() {
        logout();
      },
      content: '确实退出登录?',
    })
  }, [])
  return (
    <div className={styles.popView}>
      <div className={styles.popHeader}>
        <div className={styles.left}>
          <div className={styles.name}>{currentUser?.cnName}</div>
          <div className={styles.phone}>{currentUser?.phone}</div>
        </div>
        <div className={styles.right}>
          <OssImage className={styles.avator} src={currentUser?.headImgUrl} preview={false} />
        </div>
      </div>
      <div className={styles.popContent}>
        {/* <div className={styles.listGroupTitle}><div>账号</div></div>
        <div className={styles.listItem}>
          <span>账号设置</span>
          <RightOutlined color="#8E909F" />
        </div>
        <div className={styles.listItem}>
          <span>同步设置</span>
          <RightOutlined color="#8E909F" />
        </div>
        <div className={styles.listGroupTitle}><div>其他</div></div>
        <div className={styles.listItem}>
          <span>系统版本</span>
          <RightOutlined color="#8E909F" />
        </div>
        <div className={styles.listItem}>
          <span>关于易云</span>
          <RightOutlined color="#8E909F" />
        </div> */}
        <div className={styles.btnGroup}>
          <Button className={styles.logout} type="link" onClick={tryLogout}>退出登录</Button>
        </div>
      </div>
    </div>
  )
}