import classNames from 'classnames';
import dayjs from 'dayjs';
import React, { CSSProperties, useMemo } from 'react';
import { memo } from 'react';
import FileIcon from '../FileIcon';
import ATooltip from '../Tooltip';
import styles from './FileStatus.less';
import { CloseCircleFilled, CheckCircleFilled } from '@ant-design/icons';
import { Progress, Button } from 'antd';

interface FileStatusProps {
  className?: string;
  style?: CSSProperties;
}


export default function FileStatus(props: FileStatusProps & LoadDescProps) {
  const { className, style, ...restProps } = props;
  return (
    <div className={classNames(styles.fileStatus, className)} style={style}>
      <div className={styles.left}>
        <FileIcon className={styles.icon} extension="folder" />
        <div className={styles.content}>
          <ATooltip placement="top" title="123">
            <div className={styles.fileName}>文件名称文件名称文件名称文件名称文件名称文件名称文件名称文件名称文件名称文件名称文件名称文件名称</div>
          </ATooltip>
          <div className={styles.subContent}>
            <ATooltip placement="bottom" title="456">
              <div className={styles.filePath}>文件路径文件路径文件路径文件路径文件路径文件路径</div>
            </ATooltip>
            <div className={styles.modifyInfo}>XX创建/XX同步</div>
          </div>
        </div>
      </div>
      <div className={styles.mid}>
        <LoadDesc {...restProps} />
        {
          restProps.loadingState === 'complete'
            ? <Time time="2020-01-01 18:24:56" />
            : null
        }
      </div>
      <div className={styles.right}>
        {/* 查看1: 已下载 文件打开文件夹 */}
        {/* 查看2: 未下载 且 已删除 文件跳转到web端 */}
        {/* 下载: 未下载 且 未删除 文件 */}
        {/* 重新下载: 下载失败时出现 */}
        {/* 重新上传: 上传失败时出现 */}
        {/* <Button type="link" className={styles.button} size="small">重新上传</Button> */}
        <Button type="link" className={styles.button} size="small">暂停</Button>
        <Button type="link" className={styles.button} size="small">取消</Button>
      </div>
    </div>
  )
}

const Time = memo((props: { time: string }) => (
  <span className={styles.time}>{dayjs(props.time).format('HH:mm:ss')}</span>
));

interface LoadDescProps {
  type: 'upload' | 'download';
  loadingState: 'loading' | 'complete';
  result?: 'success' | 'fail';
  progress?: number;
}

function LoadDesc(props: LoadDescProps) {
  const { result, type, loadingState, progress } = props;
  const keywords = type === 'upload' ? '上传' : '下载';
  const [resultText, icon] = useMemo(() => {
    if (result === 'success') { return ['成功', <CheckCircleFilled className={classNames(styles.stateIcon, styles.success)} />]; }
    if (result === 'fail') { return ['失败', <CloseCircleFilled className={classNames(styles.stateIcon, styles.error)} />]; }
    return ['', null];
  }, [result]);
  return (
    <span className={styles.loadDesc}>
      {
        loadingState === 'loading'
          ? <Progress percent={progress} format={() => `${keywords}中...`} />
          : (
            <>
              {icon}
              {keywords}
              {resultText}!
            </>
          )
      }
    </span>
  )
}